@@ -15,6 +15,7 @@
 #include <sys/stat.h>
 #include <dirent.h>
 #include <string.h>
+#include <stdio.h>
 #include <popt-gnome.h>
 #include <glib.h>
 /* I know, that is is not nice, but that is exactly, what xml-config gives us */
@@ -93,21 +94,22 @@ static void gfi_try_srcfile (const gchar *name);
 static void gfi_try_srcfont (xmlNodePtr node);
 
 static const struct poptOption options[] = {
-  { "debug", 'd', POPT_ARG_NONE, &gfi_debug, 0,
-    N_("Print out debugging information"), NULL },
-  { "target", 't', POPT_ARG_STRING, &target, 0,
-    N_("Output file name"), NULL },
-  { NULL, '\0', POPT_ARG_CALLBACK, &add_path, 0 },
-  { "fontmap-path", 'f', POPT_ARG_STRING, NULL, 0,
-    N_("Search this path for .font files."), N_("PATH") },
-  { "afm-path", 'a', POPT_ARG_STRING, NULL, 0,
-    N_("Base for relative afm file names."), N_("PATH") },
-  { "pfb-path", 'p', POPT_ARG_STRING, NULL, 0,
-    N_("Base for relative pfb file names."), N_("PATH") },
-  { NULL, '\0', POPT_ARG_CALLBACK, &add_assignment, 0 },
-  { "assignment", 'A', POPT_ARG_STRING, NULL, 0,
-    N_("Use this to set up a key/value pair for font files."), N_("PATH") },
-  { NULL, '\0', 0, NULL, 0 }
+	{ "debug", 'd', POPT_ARG_NONE, &gfi_debug, 0,
+	  N_("Print out debugging information"), NULL },
+	{ "target", 't', POPT_ARG_STRING, &target, 0,
+	  N_("Output file name"), NULL },
+	{ NULL, '\0', POPT_ARG_CALLBACK, &add_path, 0 },
+	{ "fontmap-path", 'f', POPT_ARG_STRING, NULL, 0,
+	  N_("Search this path for .font files."), N_("PATH") },
+	{ "afm-path", 'a', POPT_ARG_STRING, NULL, 0,
+	  N_("Base for relative afm file names."), N_("PATH") },
+	{ "pfb-path", 'p', POPT_ARG_STRING, NULL, 0,
+	  N_("Base for relative pfb file names."), N_("PATH") },
+	{ NULL, '\0', POPT_ARG_CALLBACK, &add_assignment, 0 },
+	{ "assignment", 'A', POPT_ARG_STRING, NULL, 0,
+	  N_("Use this to set up a key/value pair for font files."), N_("KEY,PATH") },
+	POPT_AUTOHELP
+	{ NULL, '\0', 0, NULL, 0 }
 };
 
 static GSList * fontmappath_list = NULL;
@@ -150,34 +152,34 @@ int main (int argc, const char ** argv)
 	args = (char **) poptGetArgs (ctx);
 
 	/* Step 1: Read existing fontmap */
-	if (gfi_debug) g_print ("Reading fontmap... ");
+	if (gfi_debug) fprintf (stderr, "Reading fontmap... ");
 	map = gp_fontmap_get ();
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/* Verify fonts */
 	/* ? maybe after reading other fontmaps? */
 
-	if (gfi_debug) g_print ("Verifying fontmap entries ");
+	if (gfi_debug) fprintf (stderr, "Verifying fontmap entries ");
 	for (l = map->fonts; l != NULL; l = l->next) {
 		gfi_verify_font_entry ((GPFontEntry *) l->data);
-		if (gfi_debug) g_print (".");
+		if (gfi_debug) fprintf (stderr, ".");
 	}
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/* Process .font files */
 
-	if (gfi_debug) g_print ("Scanning source maps... ");
+	if (gfi_debug) fprintf (stderr, "Scanning source maps... ");
 	gfi_scan_srcpaths (fontmappath_list);
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/* Process directories */
 
-	if (gfi_debug) g_print ("Scanning directories: ");
+	if (gfi_debug) fprintf (stderr, "Scanning directories: ");
 	for (i = 0; args && args[i]; i++) {
-		if (gfi_debug) g_print ("%s ", args[i]);
+		if (gfi_debug) fprintf (stderr, "%s ", args[i]);
 		gfi_scan_directory (args[i]);
 	}
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/* Free popt context */
 
@@ -194,9 +196,9 @@ int main (int argc, const char ** argv)
 
 	/* Sort all files into fonts */
 
-	if (gfi_debug) g_print ("Sorting fonts... ");
+	if (gfi_debug) fprintf (stderr, "Sorting fonts... ");
 	gfi_sort_fonts ();
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/*
 	 * Now we are ready to process fonts
@@ -205,18 +207,22 @@ int main (int argc, const char ** argv)
 	 *
 	 */
 
-	if (gfi_debug) g_print ("Sorting Type1 aliases... ");
+	if (gfi_debug) fprintf (stderr, "Sorting Type1 aliases... ");
 	gfi_process_type1_aliases ();
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
 
 	/*
 	 * And build fonts from remaining afm/pfb files
 	 *
 	 */
 
-	if (gfi_debug) g_print ("Building fonts... ");
+	if (gfi_debug) fprintf (stderr, "Building fonts... ");
 	gfi_build_fonts ();
-	if (gfi_debug) g_print ("Done\n");
+	if (gfi_debug) fprintf (stderr, "Done\n");
+
+	if (!goodfont_list) {
+		if (gfi_debug) fprintf (stderr, "Something went wrong - NO FONTS\n");
+	}
 
 	/*
 	 * Write fontmap
@@ -224,6 +230,7 @@ int main (int argc, const char ** argv)
 	 */
 
 	if (target) {
+		umask (022);
 		of = fopen (target, "w");
 		if (of) {
 			gfi_write_fontmap (of);
@@ -307,7 +314,7 @@ gfi_verify_afm_file (GPFontEntry * e, GPFileEntry * f)
 		g_hash_table_insert (goodafm_dict, fd->entry.name, fd);
 	} else {
 #ifdef GFI_VERBOSE
-		if (gfi_debug) g_print ("Not good: %s\n", f->name);
+		if (gfi_debug) fprintf (stderr, "Not good: %s\n", f->name);
 #endif
 	}
 }
@@ -340,7 +347,7 @@ gfi_verify_pfb_file (GPFontEntry * e, GPFileEntry * f)
 		g_hash_table_insert (goodpfb_dict, fd->entry.name, fd);
 	} else {
 #ifdef GFI_VERBOSE
-		if (gfi_debug) g_print ("Not good: %s\n", f->name);
+		if (gfi_debug) fprintf (stderr, "Not good: %s\n", f->name);
 #endif
 	}
 }
@@ -460,23 +467,38 @@ gfi_scan_directory (const gchar * name)
 			g_free (fn);
 		}
 	} else {
-		if (gfi_debug) g_print ("Invalid directory: %s\n", name);
+		if (gfi_debug) fprintf (stderr, "Invalid directory: %s\n", name);
 	}
 }
 
 static void
-gfi_try_font_file (const gchar * name)
+gfi_try_font_file (const gchar *fn)
 {
 	GFIFileData * fd;
 	struct stat s;
+	gchar *name;
 
-	if (stat (name, &s) < 0) return;
+	if (stat (fn, &s) < 0) return;
 	if (!S_ISREG (s.st_mode)) return;
 
+	if (!g_path_is_absolute (fn)) {
+		gchar *cdir;
+		cdir = g_get_current_dir ();
+		name = g_concat_dir_and_file (cdir, fn);
+	} else {
+		name = g_strdup (fn);
+	}
+
 	fd = g_hash_table_lookup (goodafm_dict, name);
-	if (fd) return;
+	if (fd) {
+		g_free (name);
+		return;
+	}
 	fd = g_hash_table_lookup (goodpfb_dict, name);
-	if (fd) return;
+	if (fd) {
+		g_free (name);
+		return;
+	}
 
 	/* Not registered, so try to determine file type */
 
@@ -484,6 +506,7 @@ gfi_try_font_file (const gchar * name)
 	if (fd) {
 		goodafm_list = g_slist_prepend (goodafm_list, fd);
 		g_hash_table_insert (goodafm_dict, fd->entry.name, fd);
+		g_free (name);
 		return;
 	}
 
@@ -491,9 +514,11 @@ gfi_try_font_file (const gchar * name)
 	if (fd) {
 		goodpfb_list = g_slist_prepend (goodpfb_list, fd);
 		g_hash_table_insert (goodpfb_dict, fd->entry.name, fd);
+		g_free (name);
 		return;
 	}
 
+	g_free (name);
 	/* Cannot read :( */
 }
 
@@ -657,7 +682,7 @@ gfi_process_type1_alias (GPFontEntryT1Alias * t1a)
 
 	/* Register it */
 
-	if (gfi_debug) g_print ("Registered Type1 alias: %s\n", new->t1.entry.name);
+	if (gfi_debug) fprintf (stderr, "Registered Type1 alias: %s\n", new->t1.entry.name);
 
 	goodfont_list = g_slist_prepend (goodfont_list, new);
 	g_hash_table_insert (goodfont_dict, new->t1.entry.name, new);
@@ -766,7 +791,7 @@ gfi_build_font (GFIFontData * fd)
 	parseFileFree (fi);
 
 	/* Register it */
-	if (gfi_debug) g_print ("Registered font: %s\n", new->entry.name);
+	if (gfi_debug) fprintf (stderr, "Registered font: %s\n", new->entry.name);
 
 	goodfont_list = g_slist_prepend (goodfont_list, new);
 	g_hash_table_insert (goodfont_dict, new->entry.name, new);
@@ -881,7 +906,7 @@ add_assignment (poptContext ctx, enum poptCallbackReason reason, const struct po
 
 			key = g_strdup (arg);
 			path = g_strdup (comma + 1);
-			if (gfi_debug) g_print ("Assigned %s : %s\n", key, path);
+			if (gfi_debug) fprintf (stderr, "Assigned %s : %s\n", key, path);
 
 			if (assignment_dict == NULL) assignment_dict = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -906,7 +931,7 @@ add_path (poptContext ctx, enum poptCallbackReason reason, const struct poptOpti
 			pfbpath_list = g_slist_append (pfbpath_list, g_strdup (arg));
 		}
 	} else {
-		if (gfi_debug) g_print ("%s is not a directory\n", arg);
+		if (gfi_debug) fprintf (stderr, "%s is not a directory\n", arg);
 	}
 }
 
@@ -947,7 +972,7 @@ gfi_try_srcfile (const gchar *name)
 	xmlDocPtr doc;
 	xmlNodePtr root;
 
-	if (gfi_debug) g_print ("Trying srcfile %s\n", name);
+	if (gfi_debug) fprintf (stderr, "Trying srcfile %s\n", name);
 
 	doc = xmlParseFile (name);
 	if (doc) {
