@@ -94,6 +94,23 @@ static void
 gnome_font_face_init (GnomeFontFace * face)
 {
 	face->private = g_new0 (GnomeFontFacePrivate, 1);
+
+	/* Fill fake values to be used, if file is bad */
+	face->private->weight_code = GNOME_FONT_BOOK;
+	face->private->italic = FALSE;
+	face->private->fixed_width = TRUE;
+
+	face->private->ascender = 900;
+	face->private->descender = 0;
+	face->private->underline_position = -20;
+	face->private->underline_thickness = 10;
+	face->private->capheight = 900.0;
+	face->private->italics_angle = 0.0;
+	face->private->xheight = 600.0;
+	face->private->bbox.x0 = 0.0;
+	face->private->bbox.y0 = 0.0;
+	face->private->bbox.x1 = 750.0;
+	face->private->bbox.y1 = 950.0;
 }
 
 static gboolean
@@ -199,7 +216,7 @@ gnome_font_face_get_arg (GtkObject * object, GtkArg * arg, guint arg_id)
 		if (face->private->entry->type == GP_FONT_ENTRY_TYPE1_ALIAS) {
 			GTK_VALUE_STRING (*arg) = g_strdup (((GPFontEntryT1Alias *) face->private->entry)->alias);
 		} else if (face->private->entry->type == GP_FONT_ENTRY_TYPE1) {
-			GTK_VALUE_STRING (*arg) = g_strdup (((GPFontEntryT1 *) face->private->entry)->pfb.name);
+			GTK_VALUE_STRING (*arg) = g_strdup (face->private->entry->psname);
 		} else {
 			GTK_VALUE_STRING (*arg) = NULL;
 		}
@@ -347,7 +364,10 @@ gnome_font_face_get_glyph_stdadvance (const GnomeFontFace * face, gint glyph, Ar
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
 	g_return_val_if_fail (advance != NULL, NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	if ((glyph < 0) || (glyph >= face->private->num_glyphs)) glyph = 0;
 
@@ -362,7 +382,10 @@ gnome_font_face_get_glyph_stdbbox (const GnomeFontFace * face, gint glyph, ArtDR
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
 	g_return_val_if_fail (bbox != NULL, NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	if ((glyph < 0) || (glyph >= face->private->num_glyphs)) glyph = 0;
 
@@ -380,8 +403,14 @@ gnome_font_face_get_glyph_stdoutline (const GnomeFontFace * face, gint glyph)
 
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
-	g_return_val_if_fail (GFF_LOADEDFONT (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
+	if (!GFF_LOADEDFONT (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load font", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	if ((glyph < 0) || (glyph >= face->private->num_glyphs)) glyph = 0;
 
@@ -425,7 +454,10 @@ gnome_font_face_get_ascender (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, 0.0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0.0);
-	g_return_val_if_fail (GFF_METRICS (face), 0.0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0.0;
+	}
 
 	return face->private->ascender;
 }
@@ -435,7 +467,10 @@ gnome_font_face_get_descender (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, 0.0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0.0);
-	g_return_val_if_fail (GFF_METRICS (face), 0.0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0.0;
+	}
 
 	return face->private->descender;
 }
@@ -445,7 +480,10 @@ gnome_font_face_get_underline_position (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, 0.0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0.0);
-	g_return_val_if_fail (GFF_METRICS (face), 0.0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0.0;
+	}
 
 	return face->private->underline_position;
 }
@@ -455,7 +493,10 @@ gnome_font_face_get_underline_thickness (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, 0.0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0.0);
-	g_return_val_if_fail (GFF_METRICS (face), 0.0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0.0;
+	}
 
 	return face->private->underline_thickness;
 }
@@ -497,7 +538,10 @@ gnome_font_face_get_glyph_width (const GnomeFontFace * face, gint glyph)
 {
 	g_return_val_if_fail (face != NULL, 0.0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0.0);
-	g_return_val_if_fail (GFF_METRICS (face), 0.0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0.0;
+	}
 
 	if ((glyph < 0) || (glyph >= face->private->num_glyphs)) glyph = 0;
 
@@ -515,7 +559,10 @@ gnome_font_face_get_sample (const GnomeFontFace * face)
 
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	/* This is slow and experimental */
 
@@ -568,7 +615,10 @@ gnome_font_face_lookup_default (const GnomeFontUnsized * face, gint unicode)
 
 	g_return_val_if_fail (face != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), -1);
-	g_return_val_if_fail (GFF_METRICS (face), -1);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return -1;
+	}
 
 	/* fixme: Nobody should ask mapping of 0 */
 	if (unicode < 1) return 0;
@@ -588,7 +638,10 @@ gnome_font_face_get_num_glyphs (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, 0);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), 0);
-	g_return_val_if_fail (GFF_METRICS (face), 0);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return 0;
+	}
 
 	return face->private->num_glyphs;
 }
@@ -602,7 +655,10 @@ gnome_font_face_get_glyph_ps_name (const GnomeFontFace * face, gint glyph)
 {
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	if ((glyph < 0) || (glyph >= face->private->num_glyphs)) glyph = 0;
 
@@ -624,7 +680,7 @@ read_int32_lsb (const char *p)
 static char *
 pfb_to_flat (const char *input, int input_size)
 {
-  const unsigned char *in = (unsigned char *)input;
+	const unsigned char *in = (unsigned char *)input;
   char *flat;
   int flat_size, flat_size_max;
   int in_idx;
@@ -696,52 +752,84 @@ gchar *
 gnome_font_face_get_pfa (const GnomeFontUnsized *font)
 {
 	GPFontEntryT1 * t1;
-  const char *pfb_fn;
-  FILE *f;
-  char *pfb;
-  int pfb_size, pfb_size_max;
-  int bytes_read;
+	const char *pfb_fn;
+	FILE *f;
+	char *pfb;
+	int pfb_size, pfb_size_max;
+	int bytes_read;
 
-  char *flat;
+	char *flat = NULL;
 
-  if (font == NULL) return NULL;
+	g_return_val_if_fail (font != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_FONT_FACE (font), NULL);
 
-  t1 = (GPFontEntryT1 *) font->private->entry;
-  pfb_fn = t1->pfb.name;
-  f = fopen (pfb_fn, "r");
-  if (f == NULL)
-    {
-      g_warning (_("Couldn't open font file %s\n"), pfb_fn);
-      return NULL;
-    }
-  
-  pfb_size = 0;
-  pfb_size_max = 32768;
-  pfb = g_new (char, pfb_size_max);
-  while (1)
-    {
-      bytes_read = fread (pfb + pfb_size, 1, pfb_size_max - pfb_size, f);
-      if (bytes_read == 0) break;
-      pfb_size += bytes_read;
-      pfb = g_realloc (pfb, pfb_size_max <<= 1);
-    }
+	t1 = (GPFontEntryT1 *) font->private->entry;
+	pfb_fn = t1->pfb.name;
+	f = fopen (pfb_fn, "r");
+	if (f != NULL) {
+		pfb_size = 0;
+		pfb_size_max = 32768;
+		pfb = g_new (char, pfb_size_max);
+		while (1) {
+			bytes_read = fread (pfb + pfb_size, 1, pfb_size_max - pfb_size, f);
+			if (bytes_read == 0) break;
+			pfb_size += bytes_read;
+			pfb = g_realloc (pfb, pfb_size_max <<= 1);
+		}
 
-  if (pfb_size)
-    {
-      if (((unsigned char *)pfb)[0] == 128)
-	flat = pfb_to_flat (pfb, pfb_size);
-      else
-	{
-	  flat = g_new (char, pfb_size + 1);
-	  memcpy (flat, pfb, pfb_size);
-	  flat[pfb_size] = 0;
+		if (pfb_size) {
+			if (((unsigned char *)pfb)[0] == 128) {
+				flat = pfb_to_flat (pfb, pfb_size);
+			} else {
+				flat = g_new (char, pfb_size + 1);
+				memcpy (flat, pfb, pfb_size);
+				flat[pfb_size] = 0;
+			}
+		} else {
+			flat = NULL;
+		}
+		g_free (pfb);
+		fclose (f);
+	} else {
+		gchar *privname;
+		/* Encode empty font */
+		g_warning (_("Couldn't generate pfa for face %s\n"), pfb_fn);
+		if (font->private->entry->type == GP_FONT_ENTRY_TYPE1_ALIAS) {
+			privname = ((GPFontEntryT1Alias *) font->private->entry)->alias;
+		} else {
+			privname = font->private->entry->psname;
+		}
+		flat = g_strdup_printf ("%%Empty font generated by gnome-print\n"
+					"8 dict begin"
+					"/FontType 3 def\n"
+					"/FontMatrix [.001 0 0 .001 0 0] def\n"
+					"/FontBBox [0 0 750 950] def\n"
+					"/Encoding 256 array def\n"
+					"0 1 255 {Encoding exch /.notdef put} for\n"
+					"/CharProcs 2 dict def\n"
+					"CharProcs begin\n"
+					"/.notdef {\n"
+					"0 0 moveto 750 0 lineto 750 950 lineto 0 950 lineto closepath\n"
+					"50 50 moveto 700 50 lineto 700 900 lineto 50 900 lineto closepath\n"
+					"eofill\n"
+					"} bind def\n"
+					"end\n"
+					"/BuildGlyph {\n"
+					"1000 0 0 0 750 950 setcachedevice\n"
+					"exch /CharProcs get exch\n"
+					"2 copy known not {pop /.notdef} if\n"
+					"get exec\n"
+					"} bind def\n"
+					"/BuildChar {1 index /Encoding get exch get\n"
+					"1 index /BuildGlyph get exec\n"
+					"} bind def\n"
+					"currentdict\n"
+					"end\n"
+					"/%s exch definefont pop\n",
+					privname);
 	}
-    }
-  else
-    flat = NULL;
 
-  g_free (pfb);
-  return flat;
+	return flat;
 }
 
 /*
@@ -789,7 +877,9 @@ gnome_font_face_gt1_load (GnomeFontFace * face)
 	if (!face->private->loadedfont) {
 		g_return_val_if_fail (t1->pfb.name != NULL, FALSE);
 		face->private->loadedfont = gt1_load_font (t1->pfb.name, face->private->privencoding);
-		g_return_val_if_fail (face->private->loadedfont != NULL, FALSE);
+		if (!face->private->loadedfont) {
+			face->private->num_glyphs = 1;
+		}
 	}
 
 	return TRUE;
@@ -807,6 +897,7 @@ gff_load_afm (GnomeFontFace * face)
 	int status;
 	gint nglyphs;
 	gint privcode;
+	gint ret = FALSE;
 
 	g_return_val_if_fail ((face->private->entry->type == GP_FONT_ENTRY_TYPE1) ||
 			      (face->private->entry->type == GP_FONT_ENTRY_TYPE1_ALIAS),
@@ -919,92 +1010,91 @@ gff_load_afm (GnomeFontFace * face)
 			priv->glyphs = g_renew (GFFGlyphInfo, priv->glyphs, nglyphs);
 			priv->num_glyphs = nglyphs;
 
-	  for (i = 0; i < fi->numOfChars; i++)
-	    {
-	      int code;
+			for (i = 0; i < fi->numOfChars; i++) {
+				int code;
 
-	      /* Get the width */
-	      code = fi->cmi[i].code;
-	      if (code >= 0 && code < 256)
-		{
-		  /* Get the ligature info */
-		  for (ligs = fi->cmi[i].ligs; ligs != NULL; ligs = ligs->next)
-		    {
-		      int succ, lig;
-		      GnomeFontLigList *ll;
-		      gint u;
+				/* Get the width */
+				code = fi->cmi[i].code;
+				if (code >= 0 && code < 256) {
+					/* Get the ligature info */
+					for (ligs = fi->cmi[i].ligs; ligs != NULL; ligs = ligs->next) {
+						int succ, lig;
+						GnomeFontLigList *ll;
+						gint u;
 
-		      /* We assume here that dingbats do not have ligatures */
-		      u = gp_unicode_from_ps (ligs->succ);
-		      succ = gnome_font_face_lookup_default (face, u);
-		      u = gp_unicode_from_ps (ligs->succ);
-		      lig = gnome_font_face_lookup_default (face, u);
-		      if ((succ > 0) && (lig > 0))
-			{
-			  ll = g_new (GnomeFontLigList, 1);
-			  ll->succ = succ;
-			  ll->lig = lig;
-			  ll->next = ligtab[code];
-			  ligtab[code] = ll;
+						/* We assume here that dingbats do not have ligatures */
+						u = gp_unicode_from_ps (ligs->succ);
+						succ = gnome_font_face_lookup_default (face, u);
+						u = gp_unicode_from_ps (ligs->succ);
+						lig = gnome_font_face_lookup_default (face, u);
+						if ((succ > 0) && (lig > 0)) {
+							ll = g_new (GnomeFontLigList, 1);
+							ll->succ = succ;
+							ll->lig = lig;
+							ll->next = ligtab[code];
+							ligtab[code] = ll;
+						}
+					}
+				}
 			}
-		    }
+
+			/* process the kern pairs */
+			for (ktabsize = 1; ktabsize < fi->numOfPairs << 1; ktabsize <<= 1);
+			ktab = g_new (GnomeFontKernPair, ktabsize);
+			face->private->kerns = ktab;
+			face->private->num_kerns = ktabsize;
+			for (i = 0; i < ktabsize; i++) {
+				ktab[i].glyph1 = -1;
+				ktab[i].glyph2 = -1;
+				ktab[i].x_amt = 0;
+			}
+
+			for (i = 0; i < fi->numOfPairs; i++) {
+				int glyph1, glyph2;
+				int j;
+				gint u;
+
+				/* We assume here that dingbats do not have kerning */
+				u = gp_unicode_from_ps (fi->pkd[i].name1);
+				glyph1 = gnome_font_face_lookup_default (face, u);
+				u = gp_unicode_from_ps (fi->pkd[i].name2);
+				glyph2 = gnome_font_face_lookup_default (face, u);
+
+				for (j = KERN_PAIR_HASH (glyph1, glyph2) & (ktabsize - 1);
+				     ktab[j].glyph1 != -1;
+				     j = (j + 1) & (ktabsize - 1));
+				ktab[j].glyph1 = glyph1;
+				ktab[j].glyph2 = glyph2;
+				ktab[j].x_amt = fi->pkd[i].xamt;
+#ifdef VERBOSE
+				debugmsg ("kern pair %s(%d) %s(%d) %d\n",
+					  fi->pkd[i].name1, glyph1,
+					  fi->pkd[i].name2, glyph2,
+					  fi->pkd[i].xamt);
+#endif
+			}
+
+#ifdef VERBOSE
+			for (i = 0; i < ktabsize; i++)
+				debugmsg ("%d %d %d\n",
+					  ktab[i].glyph1, ktab[i].glyph2, ktab[i].x_amt);
+#endif
+
+			ret = TRUE;
 		}
-	    }
 
-	  /* process the kern pairs */
-	  for (ktabsize = 1; ktabsize < fi->numOfPairs << 1; ktabsize <<= 1);
-	  ktab = g_new (GnomeFontKernPair, ktabsize);
-	  face->private->kerns = ktab;
-	  face->private->num_kerns = ktabsize;
-	  for (i = 0; i < ktabsize; i++)
-	    {
-	      ktab[i].glyph1 = -1;
-	      ktab[i].glyph2 = -1;
-	      ktab[i].x_amt = 0;
-	    }
-
-	  for (i = 0; i < fi->numOfPairs; i++)
-	    {
-	      int glyph1, glyph2;
-	      int j;
-	      gint u;
-
-	      /* We assume here that dingbats do not have kerning */
-	      u = gp_unicode_from_ps (fi->pkd[i].name1);
-	      glyph1 = gnome_font_face_lookup_default (face, u);
-	      u = gp_unicode_from_ps (fi->pkd[i].name2);
-	      glyph2 = gnome_font_face_lookup_default (face, u);
-
-	      for (j = KERN_PAIR_HASH (glyph1, glyph2) & (ktabsize - 1);
-		   ktab[j].glyph1 != -1;
-		   j = (j + 1) & (ktabsize - 1));
-	      ktab[j].glyph1 = glyph1;
-	      ktab[j].glyph2 = glyph2;
-	      ktab[j].x_amt = fi->pkd[i].xamt;
-#ifdef VERBOSE
-	      debugmsg ("kern pair %s(%d) %s(%d) %d\n",
-		       fi->pkd[i].name1, glyph1,
-		       fi->pkd[i].name2, glyph2,
-		       fi->pkd[i].xamt);
-#endif
-	    }
-
-#ifdef VERBOSE
-	  for (i = 0; i < ktabsize; i++)
-	    debugmsg ("%d %d %d\n",
-		     ktab[i].glyph1, ktab[i].glyph2, ktab[i].x_amt);
-#endif
+		if (fi) parseFileFree (fi);
+		fclose (afm_f);
 	}
 
-      if (fi)
-	parseFileFree (fi);
+	if (!ret) {
+		priv->glyphs = g_new0 (GFFGlyphInfo, 1);
+		priv->num_glyphs = 1;
+		priv->unimap = gp_uc_map_new ();
+		gff_fill_zero_glyph (face);
+	}
 
-      fclose (afm_f);
-
-      return TRUE;
-    }
-
-  return FALSE;
+	return TRUE;
 }
 
 static void
@@ -1045,7 +1135,10 @@ gnome_font_face_get_stdbbox (const GnomeFontFace * face)
 {
 	g_return_val_if_fail (face != NULL, NULL);
 	g_return_val_if_fail (GNOME_IS_FONT_FACE (face), NULL);
-	g_return_val_if_fail (GFF_METRICS (face), NULL);
+	if (!GFF_METRICS (face)) {
+		g_warning ("file %s: line %d: Face: %s: Cannot load metrics", __FILE__, __LINE__, face->private->entry->name);
+		return NULL;
+	}
 
 	return &face->private->bbox;
 }
