@@ -93,6 +93,13 @@ const gchar * gnome_font_face_get_family_name (const GnomeFontFace * face);
 const gchar * gnome_font_face_get_species_name (const GnomeFontFace * face);
 const gchar * gnome_font_face_get_ps_name (const GnomeFontFace * face);
 
+/*
+ * General information
+ *
+ */
+
+gint gnome_font_face_get_num_glyphs (const GnomeFontFace * face);
+
 /*
  * Get glyph number from unicode char
  *
@@ -113,6 +120,8 @@ gint gnome_font_face_lookup_default (const GnomeFontFace * face, gint unicode);
  * All face metrics are given in 0.001 em units
  */
 
+const ArtDRect * gnome_font_face_get_stdbbox (const GnomeFontFace * face);
+
 ArtPoint * gnome_font_face_get_glyph_stdadvance (const GnomeFontFace * face, gint glyph, ArtPoint * advance);
 ArtDRect * gnome_font_face_get_glyph_stdbbox (const GnomeFontFace * face, gint glyph, ArtDRect * bbox);
 const ArtBpath * gnome_font_face_get_glyph_stdoutline (const GnomeFontFace * face, gint glyph);
