@@ -309,8 +309,8 @@ gnome_print_master_print (GnomePrintMaster *gpm)
 	} else
 		gtk_object_ref (GTK_OBJECT (printer));
 
-	output = gnome_print_context_new_with_paper_size (printer,
-											gnome_paper_name (gpm->paper));
+	output = gnome_print_context_new_with_paper_size (printer, gnome_paper_name (gpm->paper));
+
 	if (output == NULL) {
 		gtk_object_unref (GTK_OBJECT (printer));
 		return -1;
