@@ -612,8 +612,6 @@ meta_close (GnomePrintContext *pc)
 	gint32 l;
 	GnomePrintMeta *meta = GNOME_PRINT_META (pc);
 
-	encode_int (pc, GNOME_META_CLOSE);
-
 	l = g_htonl (meta->buffer_size);
 	/* we cannot just map the header to memory, so poke it manually */
 	/* Note: unaligned access -- MW.  */
@@ -1256,8 +1254,8 @@ do_render (GnomePrintContext *dest, const char *data, int size, int pages)
 			break;
 
 		case GNOME_META_CLOSE:
-			gnome_print_context_close (dest);
-			return TRUE;
+			g_warning ("CLOSE encountered in metafile - possible version conflict");
+			break;
 
 		case GNOME_META_SETOPACITY:
 			data = decode_double (data, &o);
