@@ -184,7 +184,7 @@ gnome_print_context_new_with_paper_size (GnomePrinter *printer, const char *pape
 	} else if (strcmp (driver, "gnome-print-ps2") == 0) {
 		GnomePrintPs2 *ps2;
 		GnomePrintContext *frgba;
-		ps2 = gnome_print_ps2_new (printer);
+		ps2 = gnome_print_ps2_new (printer, paper_size);
 		if (!GNOME_IS_PRINT_PS2 (ps2))
 			return NULL;
 		frgba = gnome_print_frgba_new ((GnomePrintContext *) ps2);
