@@ -1253,7 +1253,7 @@ gdf_find_measured_gdk_font (const gchar * name, GnomeFontWeight weight, gboolean
 
 		/* Clear unimportant fields */
 		g_snprintf (xname, 1024, "-*-%s-%s-%s-%s-*-%d-*-*-*-*-*-%s",
-			    c[2], c[3], c[4], c[5], pxsize, "*" /* c[13] */);
+			    c[2], c[3], c[4], c[5], pxsize, "*-*" /* c[13] */);
 #ifdef VERBOSE
 		g_print ("Trying: %s\n", xname);
 #endif
