@@ -4,6 +4,9 @@
 #define __GT1_MISC_H__
 
 #include <stdlib.h> /* for malloc, etc. */
+#include <libgnome/gnome-defs.h>
+
+BEGIN_GNOME_DECLS
 
 #define gt1_alloc malloc
 #define gt1_free free
@@ -30,7 +33,10 @@ typedef unsigned char uchar;
 #define M_PI 3.14159265358979323846
 #endif  /*  M_PI  */
 
+
 void
 gt1_die (const char *fmt, ...);
 
+END_GNOME_DECLS
+
 #endif /* __GT1_MISC_H__ */
