@@ -13,7 +13,7 @@ BEGIN_GNOME_DECLS
 */
 
 typedef struct _Gt1LoadedFont Gt1LoadedFont;
-Gt1LoadedFont * gt1_load_font (const char *filename);
+Gt1LoadedFont * gt1_load_font (const char *filename, GHashTable * privencoding);
 void gt1_unload_font (Gt1LoadedFont *);
 
 typedef struct {
